@@ -521,10 +521,11 @@ IO ハンドルが L<Form|Tripletail::Form> に格納される。
 また、 L<Tripletail::Session> が有効になっている場合は、セッションデータを
 L<クッキー|Tripletail::Cookie> から読み出す。
 
-クエリの文字コードは自動判別され、文字コード変換には Encode が優先される。
+クエリの文字コードはINIのL<charset|Tripletail::InputFilter/"charset">が指定されていればそれが使用される。
+指定されていない場合は自動判別され、文字コード変換には Encode が優先される。
 Encode が利用可能でない場合はUnicode::Japaneseが用いられる。
 
-文字コードの判別は、フォームの中の CCC キーに含まれる「愛」という文字列によって行われる。
+文字コードの自動判別は、フォームの中の CCC キーに含まれる「愛」という文字列によって行われる。
 通常、 TL から出力された HTML には、自動的にこの情報が追加されるが、
 外部の静的な HTML や FLASH コンテンツ等からフォームデータを渡す場合は、
 追加する必要がある。
